/*
	*
	* This file is a part of CoreFM.
	* A file manager for CuboCore Application Suite
    * Copyright 2019 CuboCore Group
	*

	*
	* This program is free software; you can redistribute it and/or modify
	* it under the terms of the GNU General Public License as published by
	* the Free Software Foundation; either version 3 of the License, or
	* (at your option) any later version.
	*

	*
	* This program is distributed in the hope that it will be useful,
	* but WITHOUT ANY WARRANTY; without even the implied warranty of
	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	* GNU General Public License for more details.
	*

	*
	* You should have received a copy of the GNU General Public License
	* along with this program; if not, write to the Free Software
	* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
	* MA 02110-1301, USA.
	*
*/

#include "global.hpp"
#include <cprime/capplication.h>
#include "corefm.h"

int main( int argc, char** argv )
{
	#if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
		QApplication::setAttribute( Qt::AA_EnableHighDpiScaling );
	#endif

	CApplication app( "CoreFM", argc, argv );

	/* Disable root access */
	if ( not geteuid() ) {
		QMessageBox::critical(
			nullptr,
			"CoreFM - Root access disabled",
			"You are trying to run CoreFM as root. This is potentially dangerous, if you accidentally delete system files. "
			"To avoid such damage to system files, CoreFM will now close."
		);

		return 256;
	}

	if ( app.isRunning() ) {
		qDebug() << "Running instance found.";
		qDebug() << "Requesting new window.";

		if ( argc >= 2 )
			app.sendMessage( argv[ 1 ] );

		else
			app.sendMessage( sm->value( "CoreFM", "StartupPath" ) );

		return 0;
    }

    corefm *UI;
	if ( argc >= 2 )
		UI = new corefm( argv[ 1 ] );

	else
		UI = new corefm( sm->value( "CoreFM", "StartupPath" ) );

    UI->show();

	QObject::connect( &app, SIGNAL( messageReceived( const QString ) ), UI, SLOT( newWindow( QString ) ) );

	return app.exec();
};
